@@ -11,10 +11,11 @@ import zlib
 from .utils import crack_uid
 
 
-class FontSize(Enum):
+class DmFontSize(Enum):
     """
     字体大小枚举。
     """
+
     EXTREME_SMALL = 12
     SUPER_SMALL = 16
     SMALL = 18
@@ -24,34 +25,39 @@ class FontSize(Enum):
     EXTREME_BIG = 64
 
 
-class Mode(Enum):
+class DmMode(Enum):
     """
     弹幕模式枚举。
     """
+
     FLY = 1
     TOP = 5
     BOTTOM = 4
     REVERSE = 6
 
+
 class Danmaku:
     """
     弹幕类。
     """
-    def __init__(self,
-                 text: str,
-                 dm_time: float = 0.0,
-                 send_time: float = time.time(),
-                 crc32_id: str = None,
-                 color: str = 'ffffff',
-                 weight: int = -1,
-                 id_: int = -1,
-                 id_str: str = "",
-                 action: str = "",
-                 mode: Mode = Mode.FLY,
-                 font_size: FontSize = FontSize.NORMAL,
-                 is_sub: bool = False,
-                 pool: int = 0,
-                 attr: int = -1):
+
+    def __init__(
+        self,
+        text: str,
+        dm_time: float = 0.0,
+        send_time: float = time.time(),
+        crc32_id: str = None,
+        color: str = "ffffff",
+        weight: int = -1,
+        id_: int = -1,
+        id_str: str = "",
+        action: str = "",
+        mode: DmMode = DmMode.FLY,
+        font_size: DmFontSize = DmFontSize.NORMAL,
+        is_sub: bool = False,
+        pool: int = 0,
+        attr: int = -1,
+    ):
         """
         Args:
             text      (str)               : 弹幕文本。
@@ -84,7 +90,7 @@ class Danmaku:
         self.pool = pool
         self.attr = attr
 
-        self.uid = None
+        self.uid = self.crack_uid()
 
     def __str__(self):
         ret = "%s, %s, %s" % (self.send_time, self.dm_time, self.text)
@@ -96,16 +102,41 @@ class Danmaku:
     def crack_uid(self):
         """
         暴力破解 UID。
-        10.0.1: 已改为 zlib，误差可以看 zlib 官方文档(找 PSF 的文档，应该没误差)。
+        10.0.1: 已改为 zlib。
         几个测试和原来暴力破解结果一样。
 
         Returns:
             int: 真实 UID。
         """
-        self.uid = zlib.crc32(self.crc32_id.encode('utf8'))
+        self.uid = zlib.crc32(self.crc32_id.encode("utf8"))
         return self.uid
 
+    def get_information(self):
+        """
+        获取弹幕信息
+        """
+        return {
+            "text": self.text, 
+            "dm_time": self.dm_time, 
+            "send_time": self.send_time, 
+            "crc32_id": self.crc32_id, 
+            "color": self.color, 
+            "weight": self.weight, 
+            "id": self.id, 
+            "id_str": self.id_str, 
+            "action": self.action, 
+            "mode": self.mode, 
+            "font_size": self.font_size, 
+            "is_sub": self.is_sub, 
+            "pool": self.pool, 
+            "attr": self.attr, 
+            "uid": self.uid
+        }
+
     def to_xml(self):
+        """
+        将弹幕转换为 xml 格式弹幕
+        """
         txt = self.text.replace("&", "&amp;").replace("<", "&lt;").replace(">", "&gt;")
         string = f'<d p="{self.dm_time},{self.mode},{self.font_size},{int(self.color, 16)},{self.send_time},{self.pool},{self.crc32_id},{self.id},11">{txt}</d>'
         return string
